Module decoder

Module decoder 

Public GPU decode entry points.

Structs

GpuDecoder
GPU-backed decoder using vyre’s cached runtime device.

Functions

decode_base64
Decode base64 regions and concatenate their decoded bytes.
decode_bytes
Decode a byte buffer as one format and concatenate decoded regions.
decode_file
Decode bytes recursively on the GPU.
decode_file_with_rules
Decode bytes recursively using caller-provided rules on the GPU.
decode_hex
Decode hex regions and concatenate their decoded bytes.
decode_recursive_gpu
decode_recursive_gpu function.
decode_regions
Decode all regions of format using the GPU decoder.
decode_unicode
Decode unicode escape regions and concatenate their decoded bytes.
decode_url
Decode URL percent-encoded regions and concatenate their decoded bytes.