PooledBuffer

Struct PooledBuffer 

pub struct PooledBuffer { /* private fields */ }
Buffer handle that returns to its originating BufferPool on drop.

Implementations

Source

impl PooledBuffer

pub fn size(&self) -> u64

Return the size-class allocation backing this pooled buffer.

pub fn buffer(&self) -> &Buffer

Return the inner wgpu::Buffer.

Methods from Deref<Target = Buffer>

pub fn as_entire_binding(&self) -> BindingResource<'_>

Return the binding view of the entire buffer.

pub fn as_entire_buffer_binding(&self) -> BufferBinding<'_>

Return the binding view of the entire buffer.

pub unsafe fn as_hal<A, F, R>(&self, hal_buffer_callback: F) -> R
where A: HalApi, F: FnOnce(Option<&<A as Api>::Buffer>) -> R,

Returns the inner hal Buffer using a callback. The hal buffer will be None if the backend type argument does not match with this wgpu Buffer

Safety
  • The raw handle obtained from the hal Buffer must not be manually destroyed
pub fn slice<S>(&self, bounds: S) -> BufferSlice<'_>
where S: RangeBounds<u64>,

Return a slice of a Buffer’s bytes.

Return a BufferSlice referring to the portion of self’s contents indicated by bounds. Regardless of what sort of data self stores, bounds start and end are given in bytes.

A BufferSlice can be used to supply vertex and index data, or to map buffer contents for access from the CPU. See the BufferSlice documentation for details.

The range argument can be half or fully unbounded: for example, buffer.slice(..) refers to the entire buffer, and buffer.slice(n..) refers to the portion starting at the nth byte and extending to the end of the buffer.

pub fn unmap(&self)

Flushes any pending write operations and unmaps the buffer from host memory.

pub fn destroy(&self)

Destroy the associated native resources as soon as possible.

pub fn size(&self) -> u64

Returns the length of the buffer allocation in bytes.

This is always equal to the size that was specified when creating the buffer.

pub fn usage(&self) -> BufferUsages

Returns the allowed usages for this Buffer.

This is always equal to the usage that was specified when creating the buffer.