TierPolicy

Trait TierPolicy 

pub trait TierPolicy: Send + Sync {
    // Required methods
    fn should_promote(&self, key: u64, stats: &AccessStats) -> bool;
    fn eviction_candidate(
        &self,
        tier: usize,
        entries: &FxHashMap<u64, CacheEntry>,
        tracker: &AccessTracker,
    ) -> Option<u64>;
}
Policy that decides promotion and eviction behavior.

Required Methods

fn should_promote(&self, key: u64, stats: &AccessStats) -> bool

Return true if the entry should be promoted to a faster tier.

fn eviction_candidate( &self, tier: usize, entries: &FxHashMap<u64, CacheEntry>, tracker: &AccessTracker, ) -> Option<u64>

Select a candidate for eviction from the given tier.

Implementors