pub struct BufferPool { /* private fields */ }Expand description
Device-aware reusable GPU buffer pool.
Implementations
Sourceimpl BufferPool
impl BufferPool
Sourcepub fn acquire(
&self,
device: &Device,
label: &str,
size: u64,
usage: BufferUsages,
) -> Result<PooledBuffer>
pub fn acquire( &self, device: &Device, label: &str, size: u64, usage: BufferUsages, ) -> Result<PooledBuffer>
Acquire a reusable buffer with at least size bytes and exactly usage.
Errors
Returns Error::Gpu when pool metadata cannot be locked.
Sourcepub fn release(&self, buffer: PooledBuffer)
pub fn release(&self, buffer: PooledBuffer)
Release a buffer to the pool immediately.
Sourcepub fn with_buffer<R>(
&self,
device: &Device,
label: &str,
size: u64,
usage: BufferUsages,
f: impl FnOnce(&Buffer) -> R,
) -> Result<R>
pub fn with_buffer<R>( &self, device: &Device, label: &str, size: u64, usage: BufferUsages, f: impl FnOnce(&Buffer) -> R, ) -> Result<R>
Acquire a buffer for the duration of f and release it afterward.
Errors
Returns Error::Gpu when buffer acquisition fails.